@@ -2,7 +2,7 @@
 
 # IE2G    Converts Microsoft Internet Explorer favorites to Galeon bookmarks
 # 
-# Version:   0.19  (2001-11-01)
+# Version:   0.20  (2001-11-08)
 #
 # Copyright  (C) 2001 Francesco Poli, <frx@users.sf.net>
 #                     Via Amici 19 50131 Firenze, Italy
@@ -43,7 +43,7 @@ if ( (@ARGV == 1) && ($ARGV[0] eq "--help") )
     "Option VERSION specifies target Galeon version: it must be 0.8.2 or",
     " 0.12\n\n",
     "With the option --help, display this help and exit.\n\n",
-    "IE2G version 0.19, Copyright (C) 2001 Francesco Poli\n",
+    "IE2G version 0.20, Copyright (C) 2001 Francesco Poli\n",
     "IE2G comes with ABSOLUTELY NO WARRANTY.\n",
     "This is free software, and you are welcome to redistribute it\n",
     "under certain conditions; read file `COPYING' for details.\n\n",
@@ -125,6 +125,9 @@ sub  create_category
 
         # filter category or folder name (to enforce XML syntax)
         (my $name = $dir) =~ s/&/%26/g;
+        $name =~ s/</%3C/g;
+        $name =~ s/>/%3E/g;
+        $name =~ s/"/%22/g;
 
         # open category or folder tag
         if ($target == 1)
@@ -234,9 +237,15 @@ sub  create_site
 
     # filter site name (to enforce XML syntax)
     (my $name = $filename) =~ s/&/%26/g;
+    $name =~ s/</%3C/g;
+    $name =~ s/>/%3E/g;
+    $name =~ s/"/%22/g;
 
     # filter URL (to enforce XML syntax)
     $url =~ s/&/&amp;/g;
+    $url =~ s/</&lt;/g;
+    $url =~ s/>/&gt;/g;
+    $url =~ s/"/&quot;/g;
 
     # insert site tag
     if ($target == 1)
